@@ -5,7 +5,7 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: tests/test_qty.rs $
-// $Revision: 2022-01-06T15:46:31+01:00 $
+// $Revision: 2022-01-06T17:00:38+01:00 $
 
 #[cfg(test)]
 mod quantity_with_ref_unit_tests {
@@ -212,6 +212,17 @@ mod quantity_with_ref_unit_tests {
         assert_eq!(res.amount(), amnt1 * amnt2);
         assert_eq!(res.unit(), qty1.unit());
     }
+
+    #[test]
+    fn test_div_amnt() {
+        let amnt1 = Amnt!(15.54);
+        let unit1 = FooUnit::A;
+        let amnt2 = Amnt!(3.7);
+        let qty1 = amnt1 * unit1;
+        let res = qty1 / amnt2;
+        assert_eq!(res.amount(), amnt1 / amnt2);
+        assert_eq!(res.unit(), qty1.unit());
+    }
 }
 
 #[cfg(test)]
